@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 import datetime
 import json
 
+from cuser.middleware import CuserMiddleware
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 from django.core.files import File
@@ -11,12 +12,16 @@ from django.test import Client, TestCase
 from django.utils import timezone
 from django.utils.html import escape
 
-from cuser.middleware import CuserMiddleware
-
 from tracking_fields.models import (
-    TrackingEvent, CREATE, UPDATE, DELETE, ADD, REMOVE, CLEAR,
+    ADD,
+    CLEAR,
+    CREATE,
+    DELETE,
+    REMOVE,
+    UPDATE,
+    TrackingEvent,
 )
-from tracking_fields.tests.models import Human, Pet, House, UuidModel
+from tracking_fields.tests.models import House, Human, Pet, UuidModel
 
 
 class TrackingEventTestCase(TestCase):
@@ -40,7 +45,7 @@ class TrackingEventTestCase(TestCase):
         """
         Test the CREATE event
         """
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 2
         human_event = events.last()
         assert human_event.date is not None
@@ -55,10 +60,11 @@ class TrackingEventTestCase(TestCase):
         Test the CREATE event without the cuser module
         """
         from tracking_fields import tracking
+
         tracking.CUSER = False
         self.human.age = 43
         self.human.save()
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 3
         human_event = events.last()
         assert human_event.date is not None
@@ -66,7 +72,7 @@ class TrackingEventTestCase(TestCase):
         assert human_event.object == self.human
         assert human_event.object_repr == self.human_repr
         assert human_event.user is None
-        assert human_event.user_repr == 'None'
+        assert human_event.user_repr == "None"
         tracking.CUSER = True
 
     def test_update(self):
@@ -75,7 +81,7 @@ class TrackingEventTestCase(TestCase):
         """
         self.human.age = 43
         self.human.save()
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 3
         human_event = events.last()
         assert human_event.date is not None
@@ -90,7 +96,7 @@ class TrackingEventTestCase(TestCase):
         Test the DELETE event
         """
         self.human.delete()
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 3
         human_event = events.last()
         assert human_event.date is not None
@@ -105,7 +111,7 @@ class TrackingEventTestCase(TestCase):
         Test the ADD event
         """
         self.human.pets.add(self.pet)
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 3
         human_event = events.last()
         assert human_event.date is not None
@@ -121,7 +127,7 @@ class TrackingEventTestCase(TestCase):
         """
         # Event should be the same than the one from ``test_add``
         self.pet.human_set.add(self.human)
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 3
         human_event = events.last()
         assert human_event.date is not None
@@ -137,7 +143,7 @@ class TrackingEventTestCase(TestCase):
         """
         self.human.pets.add(self.pet)
         self.human.pets.remove(self.pet)
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 4
         human_event = events.last()
         assert human_event.date is not None
@@ -154,7 +160,7 @@ class TrackingEventTestCase(TestCase):
         # Event should be the same than the one from ``test_remove``
         self.human.pets.add(self.pet)
         self.pet.human_set.remove(self.human)
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 4
         human_event = events.last()
         assert human_event.date is not None
@@ -170,7 +176,7 @@ class TrackingEventTestCase(TestCase):
         """
         self.human.pets.add(self.pet)
         self.human.pets.clear()
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 4
         human_event = events.last()
         assert human_event.date is not None
@@ -186,7 +192,7 @@ class TrackingEventTestCase(TestCase):
         """
         self.human.pets.add(self.pet)
         self.pet.human_set.clear()
-        events = TrackingEvent.objects.order_by('date').all()
+        events = TrackingEvent.objects.order_by("date").all()
         assert events.count() == 4
         human_event = events.last()
         assert human_event.date is not None
@@ -209,7 +215,7 @@ class TrackingEventTestCase(TestCase):
         """
         Test to save object with utf8 in its repr
         """
-        self.human.name = u'😵'
+        self.human.name = "😵"
         self.human.save()
         events = TrackingEvent.objects.all()
         assert events.count() == 3
@@ -229,54 +235,56 @@ class TrackedFieldModificationTestCase(TestCase):
         self.human_repr = repr(self.human)
 
     def test_create(self):
-        human_event = TrackingEvent.objects.filter(action=CREATE).order_by('date').last()
+        human_event = (
+            TrackingEvent.objects.filter(action=CREATE).order_by("date").last()
+        )
         assert human_event.fields.all().count() == 4
-        field = human_event.fields.get(field='birthday')
+        field = human_event.fields.get(field="birthday")
         assert field.new_value == json.dumps(self.human.birthday)
-        field = human_event.fields.get(field='name')
+        field = human_event.fields.get(field="name")
         assert field.new_value == json.dumps(self.human.name)
-        field = human_event.fields.get(field='age')
+        field = human_event.fields.get(field="age")
         assert field.new_value == json.dumps(self.human.age)
-        field = human_event.fields.get(field='favourite_pet')
+        field = human_event.fields.get(field="favourite_pet")
         assert field.new_value == json.dumps(self.human.favourite_pet)
 
     def test_update(self):
         self.human.age = 43
         self.human.save()
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
-        field = human_event.fields.get(field='age')
+        field = human_event.fields.get(field="age")
         assert field.old_value == json.dumps(42)
         assert field.new_value == json.dumps(43)
 
     def test_foreign_key(self):
         self.human.favourite_pet = self.pet
         self.human.save()
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
-        field = human_event.fields.get(field='favourite_pet')
+        field = human_event.fields.get(field="favourite_pet")
         assert field.old_value == json.dumps(None)
         assert field.new_value == json.dumps(str(self.pet))
 
     def test_foreign_key_not_changed(self):
-        """ Test a foreign key does not change if only other values change """
+        """Test a foreign key does not change if only other values change"""
         self.human.favourite_pet = self.pet
         self.human.save()
         self.human.name = "Toto"
         self.human.save()
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
         field = human_event.fields.first()
         assert field.old_value == json.dumps("George")
         assert field.new_value == json.dumps("Toto")
 
     def test_foreign_key_label(self):
-        """ Test label of foreign keys are used in tracked fields """
+        """Test label of foreign keys are used in tracked fields"""
         self.human.favourite_pet = self.pet
         self.human.save()
         self.human.favourite_pet = self.pet2
         self.human.save()
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
         field = human_event.fields.first()
         assert field.old_value == json.dumps(str(self.pet))
@@ -284,98 +292,83 @@ class TrackedFieldModificationTestCase(TestCase):
 
     def test_add(self):
         self.human.pets.add(self.pet2)
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
-        field = human_event.fields.get(field='pets')
+        field = human_event.fields.get(field="pets")
         assert field.old_value == json.dumps([str(self.pet)])
-        assert field.new_value == json.dumps([
-            str(self.pet), str(self.pet2)
-        ])
+        assert field.new_value == json.dumps([str(self.pet), str(self.pet2)])
 
     def test_add_reverse(self):
         self.pet2.human_set.add(self.human)
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
-        field = human_event.fields.get(field='pets')
+        field = human_event.fields.get(field="pets")
         assert field.old_value == json.dumps([str(self.pet)])
-        assert field.new_value == json.dumps([
-            str(self.pet), str(self.pet2)
-        ])
+        assert field.new_value == json.dumps([str(self.pet), str(self.pet2)])
 
     def test_remove(self):
         self.human.pets.add(self.pet2)
         self.human.pets.remove(self.pet2)
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
-        field = human_event.fields.get(field='pets')
-        assert field.old_value == json.dumps([
-            str(self.pet), str(self.pet2)
-        ])
+        field = human_event.fields.get(field="pets")
+        assert field.old_value == json.dumps([str(self.pet), str(self.pet2)])
         assert field.new_value == json.dumps([str(self.pet)])
 
     def test_remove_reverse(self):
         self.human.pets.add(self.pet2)
         self.pet2.human_set.remove(self.human)
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
-        field = human_event.fields.get(field='pets')
-        assert field.old_value == json.dumps([
-            str(self.pet), str(self.pet2)
-        ])
+        field = human_event.fields.get(field="pets")
+        assert field.old_value == json.dumps([str(self.pet), str(self.pet2)])
         assert field.new_value == json.dumps([str(self.pet)])
 
     def test_clear(self):
         self.human.pets.add(self.pet2)
         self.human.pets.clear()
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
-        field = human_event.fields.get(field='pets')
-        assert field.old_value == json.dumps([
-            str(self.pet), str(self.pet2)
-        ])
+        field = human_event.fields.get(field="pets")
+        assert field.old_value == json.dumps([str(self.pet), str(self.pet2)])
         assert field.new_value == json.dumps([])
 
     def test_clear_reverse(self):
         self.human.pets.add(self.pet2)
         self.pet2.human_set.clear()
-        human_event = TrackingEvent.objects.order_by('date').last()
+        human_event = TrackingEvent.objects.order_by("date").last()
         assert human_event.fields.all().count() == 1
-        field = human_event.fields.get(field='pets')
-        assert field.old_value == json.dumps([
-            str(self.pet), str(self.pet2)
-        ])
+        field = human_event.fields.get(field="pets")
+        assert field.old_value == json.dumps([str(self.pet), str(self.pet2)])
         assert field.new_value == json.dumps([str(self.pet)])
 
     def test_date(self):
         today = datetime.date.today()
         self.human.birthday = today
         self.human.save()
-        human_event = TrackingEvent.objects.order_by('date').last()
-        field = human_event.fields.get(field='birthday')
+        human_event = TrackingEvent.objects.order_by("date").last()
+        field = human_event.fields.get(field="birthday")
         assert field.old_value == json.dumps(None)
-        assert field.new_value == json.dumps(today.strftime('%Y-%m-%d'))
+        assert field.new_value == json.dumps(today.strftime("%Y-%m-%d"))
 
     def test_datetime(self):
         now = timezone.now()
         self.pet.vet_appointment = now
         self.pet.save()
-        pet_event = TrackingEvent.objects.order_by('date').last()
-        field = pet_event.fields.get(field='vet_appointment')
+        pet_event = TrackingEvent.objects.order_by("date").last()
+        field = pet_event.fields.get(field="vet_appointment")
         assert field.old_value == json.dumps(None)
-        assert field.new_value == json.dumps(now.strftime('%Y-%m-%d %H:%M:%S'))
+        assert field.new_value == json.dumps(now.strftime("%Y-%m-%d %H:%M:%S"))
 
     def test_imagefield(self):
-        picture = File(
-            open('tracking_fields/tests/__init__.py'),
-            'picture.png',
-        )
-        self.pet.picture = picture
-        self.pet.save()
-        pet_event = TrackingEvent.objects.order_by('date').last()
-        field = pet_event.fields.get(field='picture')
-        assert field.old_value == json.dumps(None)
-        assert field.new_value == json.dumps(self.pet.picture.path)
-        self.pet.picture.delete()
+        with File(open("tracking_fields/tests/__init__.py"), "picture.png") as picture:
+            self.pet.picture = picture
+            self.pet.save()
+            pet_event = TrackingEvent.objects.order_by("date").last()
+            field = pet_event.fields.get(field="picture")
+            assert field.old_value == json.dumps(None)
+            assert field.new_value == json.dumps(self.pet.picture.path)
+            self.pet.picture.delete()
 
 
 class TrackingRelatedTestCase(TestCase):
@@ -388,49 +381,112 @@ class TrackingRelatedTestCase(TestCase):
         self.human.name = "Tutu"
         self.human.save()
         house_event = TrackingEvent.objects.filter(
-            object_content_type=self.content_type)
+            object_content_type=self.content_type
+        )
         assert house_event.count() == 1
         house_event = house_event.last()
         assert house_event.fields.count() == 1
         field = house_event.fields.last()
         assert field.old_value == '"Toto"'
         assert field.new_value == '"Tutu"'
-        assert field.field == 'tenant__name'
+        assert field.field == "tenant__name"
 
     def test_m2m_change(self):
         pet = Pet.objects.create(name="Pet", age=4)
         self.human.pets.add(pet)
         house_event = TrackingEvent.objects.filter(
-            object_content_type=self.content_type)
+            object_content_type=self.content_type
+        )
         assert house_event.count() == 1
         house_event = house_event.last()
         assert house_event.fields.count() == 1
         field = house_event.fields.last()
-        assert field.field == 'tenant__pets'
+        assert field.field == "tenant__pets"
         assert field.old_value == json.dumps([])
         assert field.new_value == json.dumps([str(pet)])
 
 
 class AdminModelTestCase(TestCase):
-    def setUp(self):
-        self.user = User.objects.create_superuser('admin', '', 'password')
-        self.c = Client()
-        self.c.login(username="admin", password="password")
-        CuserMiddleware.set_user(self.user)
-        self.human = Human.objects.create(name="George", age=42, height=175)
+    @classmethod
+    def setUpTestData(cls):
+        cls.user = User.objects.create_superuser("admin", "", "password")
+        cls.c = Client()
+        cls.c.login(username="admin", password="password")
+        CuserMiddleware.set_user(cls.user)
+        cls.human = Human.objects.create(name="George", age=42, height=175)
+
+    def test_tracker_event_user_filter_with_incorrect_user(self):
+        """Test the admin view listing all objects given an incorrect tracking event"""
+        user_content_type = ContentType.objects.get_for_model(User)
+        TrackingEvent.objects.create(
+            action="UPDATE",
+            object=self.human,
+            object_repr=repr(self.human),
+            user_content_type=user_content_type,
+            user_id=999999,
+            user_repr="",
+        )
+        response = self.c.get("/admin/tracking_fields/trackingevent/")
+        self.assertContains(
+            response,
+            escape(repr(self.human)),
+        )
 
     def test_list(self):
-        """ Test the admin view listing all objects. """
-        response = self.c.get('/admin/tracking_fields/trackingevent/')
+        """Test the admin view listing all objects."""
+        response = self.c.get("/admin/tracking_fields/trackingevent/")
+        self.assertContains(
+            response,
+            escape(repr(self.human)),
+        )
+
+    def test_list_with_filter(self):
+        """Test the admin view listing all objects with correct filter."""
+        user_content_type = ContentType.objects.get_for_model(User)
+        response = self.c.get(
+            f"/admin/tracking_fields/trackingevent/"
+            f"?user={user_content_type.id}:{self.user.id}"
+        )
+        self.assertContains(
+            response,
+            escape(repr(self.human)),
+        )
+
+    def test_list_with_incorrect_filter_on_user_content_type(self):
+        """Test the admin view listing all objects with incorrect user content type
+        filter."""
+        response = self.c.get(
+            f"/admin/tracking_fields/trackingevent/" f"?user=99999:{self.user.id}"
+        )
+        self.assertNotContains(
+            response,
+            escape(repr(self.human)),
+        )
+
+    def test_list_with_incorrect_filter_on_user_id(self):
+        """Test the admin view listing all objects with incorrect user id filter."""
+        user_content_type = ContentType.objects.get_for_model(User)
+        response = self.c.get(
+            f"/admin/tracking_fields/trackingevent/"
+            f"?user={user_content_type.id}:99999"
+        )
+        self.assertNotContains(
+            response,
+            escape(repr(self.human)),
+        )
+
+    def test_list_with_incorrect_filter(self):
+        """Test the admin view listing all objects with incorrect filter."""
+        response = self.c.get("/admin/tracking_fields/trackingevent/?user=foobar")
         self.assertContains(
             response,
             escape(repr(self.human)),
         )
 
     def test_single(self):
-        """ Test the admin view listing all objects. """
+        """Test the admin view listing all objects."""
         event = TrackingEvent.objects.first()
-        url = '/admin/tracking_fields/trackingevent/{0}'.format(event.pk)
+        url = "/admin/tracking_fields/trackingevent/{0}".format(event.pk)
         response = self.c.get(url, follow=True)
         self.assertContains(
             response,
@@ -442,9 +498,9 @@ class AdminModelTestCase(TestCase):
         )
 
     def test_history_btn(self):
-        """ Test the tracking button is present. """
+        """Test the tracking button is present."""
         response = self.c.get(
-            '/admin/tests/human/{}'.format(self.human.pk),
+            "/admin/tests/human/{}".format(self.human.pk),
             follow=True,
         )
         self.assertContains(
@@ -457,12 +513,10 @@ class AdminModelTestCase(TestCase):
         Test the button back to the button is present
         where there is an object filter.
         """
-        content_type = ContentType.objects.get(
-            app_label="tests", model="human"
-        )
-        param = 'object={0}%3A{1}'.format(content_type.pk, self.human.pk)
+        content_type = ContentType.objects.get(app_label="tests", model="human")
+        param = "object={0}%3A{1}".format(content_type.pk, self.human.pk)
         response = self.c.get(
-            '/admin/tracking_fields/trackingevent/?{0}'.format(param),
+            "/admin/tracking_fields/trackingevent/?{0}".format(param),
             follow=True,
         )
         self.assertContains(
@@ -476,7 +530,7 @@ class AdminModelTestCase(TestCase):
         where there is no object filter.
         """
         response = self.c.get(
-            '/admin/tracking_fields/trackingevent/',
+            "/admin/tracking_fields/trackingevent/",
             follow=True,
         )
         self.assertNotContains(
